@@ -16,6 +16,7 @@ def main():
     if (os.path.exists(os.path.join(os.path.abspath(os.getcwd()), str(args.file[0])))
             and os.path.exists(os.path.join(os.path.abspath(os.getcwd()), str(args.test[0])))):
         wa = False
+        subprocess.Popen(["g++", str(args.file[0])])
         for sb, _, f in os.walk(os.path.join(os.path.abspath(os.getcwd()), str(args.test[0]))):
             for i in f:
                 pth = sb + os.sep + i
@@ -23,10 +24,10 @@ def main():
                     with open(pth, "r", encoding="utf-8") as fin:
 
                         if (args.w):
-                            p = subprocess.Popen(["g++", str(args.file[0]), r"&& .\a"], stdin=fin, stdout=subprocess.PIPE,
+                            p = subprocess.Popen([".\\a"], stdin=fin, stdout=subprocess.PIPE,
                                              stderr=subprocess.PIPE)
                         else:
-                            p = subprocess.Popen(["g++", str(args.file[0]), "&& ./a.out"], stdin=fin, stdout=subprocess.PIPE,
+                            p = subprocess.Popen(["./a.out"], stdin=fin, stdout=subprocess.PIPE,
                                              stderr=subprocess.PIPE)
                         out, err = p.communicate()
                         if not err:
